@@ -9,6 +9,7 @@ from types import TracebackType
 from typing import Any
 from typing import Generator
 from typing import Iterable
+from typing import List
 from typing import TYPE_CHECKING
 
 import attr
@@ -18,7 +19,7 @@ from _pytask.config import hookimpl
 from _pytask.config import IGNORED_TEMPORARY_FILES_AND_FOLDERS
 from _pytask.console import console
 from _pytask.exceptions import CollectionError
-from _pytask.nodes import MetaTask
+from _pytask.nodes import Task
 from _pytask.outcomes import ExitCode
 from _pytask.path import find_common_ancestor
 from _pytask.path import relative_to
@@ -26,6 +27,7 @@ from _pytask.pluginmanager import get_plugin_manager
 from _pytask.session import Session
 from _pytask.shared import get_first_non_none_value
 from _pytask.traceback import render_exc_info
+from pybaum.tree_util import tree_just_yield
 
 
 if TYPE_CHECKING:
@@ -35,7 +37,7 @@ if TYPE_CHECKING:
 _HELP_TEXT_MODE = (
     "Choose 'dry-run' to print the paths of files/directories which would be removed, "
     "'interactive' for a confirmation prompt for every path, and 'force' to remove all "
-    "unknown paths at once.  [default: dry-run]"
+    "unknown paths at once. [dim]\\[default: dry-run][/]"
 )
 
 
@@ -76,9 +78,17 @@ def pytask_post_parse(config: dict[str, Any]) -> None:
     type=click.Choice(["dry-run", "interactive", "force"]),
     help=_HELP_TEXT_MODE,
 )
-@click.option("-d", "--directories", is_flag=True, help="Remove whole directories.")
 @click.option(
-    "-q", "--quiet", is_flag=True, help="Do not print the names of the removed paths."
+    "-d",
+    "--directories",
+    is_flag=True,
+    help="Remove whole directories. [dim]\\[default: False][/]",
+)
+@click.option(
+    "-q",
+    "--quiet",
+    is_flag=True,
+    help="Do not print the names of the removed paths. [dim]\\[default: quiet][/]",
 )
 def clean(**config_from_cli: Any) -> NoReturn:
     """Clean the provided paths by removing files unknown to pytask."""
@@ -186,11 +196,11 @@ def _collect_all_paths_known_to_pytask(session: Session) -> set[Path]:
     return known_paths
 
 
-def _yield_paths_from_task(task: MetaTask) -> Generator[Path, None, None]:
+def _yield_paths_from_task(task: Task) -> Generator[Path, None, None]:
     """Yield all paths attached to a task."""
     yield task.path
     for attribute in ["depends_on", "produces"]:
-        for node in getattr(task, attribute).values():
+        for node in tree_just_yield(getattr(task, attribute)):
             if hasattr(node, "path") and isinstance(node.path, Path):
                 yield node.path
 
@@ -234,7 +244,7 @@ class _RecursivePathNode:
     """
 
     path = attr.ib(type=Path)
-    sub_nodes = attr.ib(type="list[_RecursivePathNode]")
+    sub_nodes = attr.ib(type=List["_RecursivePathNode"])
     is_dir = attr.ib(type=bool)
     is_file = attr.ib(type=bool)
     is_unknown = attr.ib(type=bool)
